#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Fri Jun  3 01:51:30 2022

@author: xieting
"""

from FX.fx import AUDUSD_return
from FX.fx import GBPEUR_return
from FX.fx import USDCAD_return
from FX.fx import USDJPY_return
from FX.fx import USDMXN_return
from FX.fx import EURUSD_return
from FX.fx import USDCNY_return
from FX.fx import USDCZK_return
from FX.fx import USDPLN_return
from FX.fx import USDINR_return
from FX.fx import USDRUB_return


